@@ -146,7 +146,7 @@ class image_update(JobServerPlugin):
                   localFile.write(chunk)
           
             # grab the kernel
-            with self.js.session.get(self.js.mprovURL + 'kernels/' + image + '.vmlinuz', stream=True) as remoteImage:
+            with self.js.session.get(self.js.mprovURL + 'images/' + image + '.vmlinuz', stream=True) as remoteImage:
               remoteImage.raise_for_status()
               os.makedirs(self.imageDir + '/' + image,exist_ok=True)
               with open(self.imageDir + '/' + image + '/' + image + '.vmlinuz', 'wb') as localFile:
@@ -154,19 +154,19 @@ class image_update(JobServerPlugin):
                   localFile.write(chunk)
             with open(self.imageDir + '/image-versions', "w") as vfile:
               vfile.write(json.dumps(imgVersions))
-        else:
-          # if our version doesn't match, and there are no jobservers, submit an image-update job to the mPCC
-          data = {
-            "params": { "imageId" : imageData['slug'] },
-            "name": "Image Update",
-            "module": "image-update",
-            "status": 1,
-            "jobserver": self.js.id,
-          }
-          #print(json.dumps(data))
-          response = self.js.session.post(f"{self.js.mprovURL}jobs/",data=json.dumps(data))
-          if response.status_code <= 199 or response.status_code >= 300:
-            print(f"Error: Could not submit update job to mPCC, status code: {response.status_code}, image: {imageData['slug']}")
+        # else:
+        #   # if our version doesn't match, and there are no jobservers, submit an image-update job to the mPCC
+        #   data = {
+        #     "params": { "imageId" : imageData['slug'] },
+        #     "name": "Image Update",
+        #     "module": "image-update",
+        #     "status": 1,
+        #     "jobserver": self.js.id,
+        #   }
+        #   #print(json.dumps(data))
+        #   response = self.js.session.post(f"{self.js.mprovURL}jobs/",data=json.dumps(data))
+        #   if response.status_code <= 199 or response.status_code >= 300:
+        #     print(f"Error: Could not submit update job to mPCC, status code: {response.status_code}, image: {imageData['slug']}")
 
   def handle_jobs(self):
     # try:
@@ -255,10 +255,10 @@ class image_update(JobServerPlugin):
         image_update.join()
         # run image-gen scripts.
     
-        # grab a copy of the jobserver wheel from the main mprov server
-        # TODO: Change this to a pip install mprov_jobserver command after publication
+        
         imgDir = self.imageDir + '/' + imageDetails['slug']
-
+        # copy in the system resolv.conf
+        os.system(f"/bin/cp -f /etc/resolv.conf {imgDir}/etc/resolv.conf")
         if os.system("chroot " + imgDir + " pip3 --no-cache-dir install --upgrade mprov_jobserver"):
           print("Error: Unable to install mprov_jobserver python module.")
           return
@@ -291,6 +291,9 @@ class image_update(JobServerPlugin):
         if os.system(imgDir + '/tmp/mprov/script-runner.sh'):
           print("Error while running image-gen scripts via job server..")
         
+        # remove the jobserver.yaml from /tmp/mprov/
+        if os.path.exists(imgDir +"/tmp/mprov/jobserver.yaml"):
+          os.unlink(imgDir + "/tmp/mprov/jobserver.yaml")
 
         # package the filesystem into an initramfs
         print("Building " + os.getcwd() + "/" + imageDetails['slug'] + '.img')
